@@ -1,5 +1,5 @@
 "composite1COP" <-
-function(u,v,para,...) {
+function(u, v, para, ...) {
   if(is.null(para$alpha)) {
     warning("no alpha parameter given")
     return(NULL)
@@ -10,7 +10,10 @@ function(u,v,para,...) {
   }
   alpha <- para$alpha; alpha.p <- 1 - alpha
   beta  <- para$beta;   beta.p <- 1 - beta
-  return(u^alpha * v^beta *
-         COP(u^alpha.p, v^beta.p, cop=para$cop1, para=para$para1, ...))
+
+  if(is.null(para$para)) para$para <- para$para1
+  if(is.null(para$cop )) para$cop  <- para$cop1
+
+  return(u^alpha * v^beta * COP(u^alpha.p, v^beta.p, para=para, ...))
 }
 
